@@ -23,6 +23,7 @@ import (
 	"os/exec"
 	"path"
 	"runtime"
+	"slices"
 	"sort"
 	"strconv"
 	"strings"
@@ -90,8 +91,8 @@ func (a *accountsMgr) Diff(ctx context.Context) (bool, error) {
 		}
 	}
 	// If we've just disabled OS Login.
-	oldOslogin, _, _ := getOSLoginEnabled(oldMetadata)
-	newOslogin, _, _ := getOSLoginEnabled(newMetadata)
+	oldOslogin, _, _, _ := getOSLoginEnabled(oldMetadata)
+	newOslogin, _, _, _ := getOSLoginEnabled(newMetadata)
 	if oldOslogin && !newOslogin {
 		return true, nil
 	}
@@ -105,7 +106,7 @@ func (a *accountsMgr) Timeout(ctx context.Context) (bool, error) {
 
 func (a *accountsMgr) Disabled(ctx context.Context) (bool, error) {
 	config := cfg.Get()
-	oslogin, _, _ := getOSLoginEnabled(newMetadata)
+	oslogin, _, _, _ := getOSLoginEnabled(newMetadata)
 	return false || runtime.GOOS == "windows" || oslogin || !config.Daemons.AccountsDaemon, nil
 }
 
@@ -214,7 +215,7 @@ func getUserKeys(mdkeys []string) map[string][]string {
 			}
 
 			if err != nil {
-				if !utils.ContainsString(trimmedKey, badSSHKeys) {
+				if !slices.Contains(badSSHKeys, trimmedKey) {
 					logger.Errorf("%s: %s", err.Error(), trimmedKey)
 					badSSHKeys = append(badSSHKeys, trimmedKey)
 				}
@@ -343,12 +344,12 @@ func createUserGroupCmd(cmd, user, group string) (string, []string) {
 // createGoogleUser creates a Google managed user account if needed and adds it
 // to the configured groups.
 func createGoogleUser(ctx context.Context, config *cfg.Sections, user string) error {
-	var uid string
+	var uid, gid string
 	if config.Accounts.ReuseHomedir {
-		uid = getUID(fmt.Sprintf("/home/%s", user))
+		uid, gid = getUIDAndGID(fmt.Sprintf("/home/%s", user))
 	}
 
-	if err := createUser(ctx, user, uid); err != nil {
+	if err := createUser(ctx, user, uid, gid); err != nil {
 		return err
 	}
 	groups := config.Accounts.Groups
@@ -411,7 +412,7 @@ func createSudoersGroup(ctx context.Context, config *cfg.Sections) error {
 // updateAuthorizedKeysFile adds provided keys to the user's SSH
 // AuthorizedKeys file. The file and containing directory are created if it
 // does not exist. Uses a temporary file to avoid partial updates in case of
-// errors. If no keys are provided, the authorized keys file is removed.
+// errors.
 func updateAuthorizedKeysFile(ctx context.Context, user string, keys []string) error {
 	gcomment := "# Added by Google"
 
@@ -441,12 +442,6 @@ func updateAuthorizedKeysFile(ctx context.Context, user string, keys []string) e
 		}
 	}
 	akpath := path.Join(sshpath, "authorized_keys")
-	// Remove empty file.
-	if len(keys) == 0 {
-		os.Remove(akpath)
-		return nil
-	}
-
 	tempPath := akpath + ".google"
 	akcontents, err := os.ReadFile(akpath)
 	if err != nil && !os.IsNotExist(err) {
