@@ -121,7 +121,8 @@ func TestFilterGoogleLines(t *testing.T) {
 	}
 
 	for idx, tt := range tests {
-		if res := filterGoogleLines(strings.Join(tt.contents, "\n")); !cmpslice(res, tt.want) {
+		// The additional "\n" at the end is because Unix text files are expected to end in a newline
+		if res := filterGoogleLines(strings.Join(tt.contents, "\n") + "\n"); !cmpslice(res, tt.want) {
 			t.Errorf("test %v\nwant:\n%v\ngot:\n%v\n", idx, tt.want, res)
 		}
 	}
@@ -189,8 +190,8 @@ func TestUpdateNSSwitchConfig(t *testing.T) {
 	}
 
 	for idx, tt := range tests {
-		contents := strings.Join(tt.contents, "\n")
-		want := strings.Join(tt.want, "\n")
+		contents := strings.Join(tt.contents, "\n") + "\n"
+		want := strings.Join(tt.want, "\n") + "\n"
 
 		if res := updateNSSwitchConfig(contents, tt.enable); res != want {
 			t.Errorf("test %v\nwant:\n%v\ngot:\n%v\n", idx, want, res)
@@ -206,6 +207,7 @@ func TestUpdateSSHConfig(t *testing.T) {
 	authorizedPrincipalsUser := "AuthorizedPrincipalsCommandUser root"
 	trustedUserCAKeys := "TrustedUserCAKeys " + sshtrustedca.DefaultPipePath
 	twoFactorAuthMethods := "AuthenticationMethods publickey,keyboard-interactive"
+	includePerUserConfigs := "Include /var/google-users.d/*"
 	matchblock1 := `Match User sa_*`
 	matchblock2 := `       AuthenticationMethods publickey`
 
@@ -233,6 +235,7 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				googleBlockStart,
+				includePerUserConfigs,
 				matchblock1,
 				matchblock2,
 				googleBlockEnd,
@@ -260,6 +263,7 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				googleBlockStart,
+				includePerUserConfigs,
 				matchblock1,
 				matchblock2,
 				googleBlockEnd,
@@ -291,6 +295,7 @@ func TestUpdateSSHConfig(t *testing.T) {
 				"line1",
 				"line3",
 				googleBlockStart,
+				includePerUserConfigs,
 				matchblock1,
 				matchblock2,
 				googleBlockEnd,
@@ -319,6 +324,7 @@ func TestUpdateSSHConfig(t *testing.T) {
 				"line1",
 				"line3",
 				googleBlockStart,
+				includePerUserConfigs,
 				matchblock1,
 				matchblock2,
 				googleBlockEnd,
@@ -345,6 +351,9 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
@@ -365,6 +374,9 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
@@ -421,19 +433,45 @@ func TestUpdateSSHConfig(t *testing.T) {
 			},
 			want: []string{
 				googleBlockStart,
-				trustedUserCAKeys,
-				authorizedPrincipalsCommand,
-				authorizedPrincipalsUser,
 				authorizedKeysCommandSk,
 				authorizedKeysUser,
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
 			skey:      true,
 			reqCerts:  false,
+			cfgCert:   false,
+		},
+		{
+			// Skey enablement disables certificates.
+			contents: []string{
+				"line1",
+				"line2",
+				googleBlockStart,
+				"line3",
+				googleBlockEnd,
+			},
+			want: []string{
+				googleBlockStart,
+				authorizedKeysCommandSk,
+				authorizedKeysUser,
+				googleBlockEnd,
+				"line1",
+				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
+			},
+			enable:    true,
+			twofactor: false,
+			skey:      true,
+			reqCerts:  true,
 			cfgCert:   true,
 		},
 		{
@@ -452,6 +490,9 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
@@ -476,6 +517,9 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
@@ -500,6 +544,9 @@ func TestUpdateSSHConfig(t *testing.T) {
 				googleBlockEnd,
 				"line1",
 				"line2",
+				googleBlockStart,
+				includePerUserConfigs,
+				googleBlockEnd,
 			},
 			enable:    true,
 			twofactor: false,
@@ -517,8 +564,8 @@ func TestUpdateSSHConfig(t *testing.T) {
 	defaultCertAuthConfig := config.OSLogin.CertAuthentication
 
 	for idx, tt := range tests {
-		contents := strings.Join(tt.contents, "\n")
-		want := strings.Join(tt.want, "\n")
+		contents := strings.Join(tt.contents, "\n") + "\n"
+		want := strings.Join(tt.want, "\n") + "\n"
 		config.OSLogin.CertAuthentication = tt.cfgCert
 
 		if res := updateSSHConfig(contents, tt.enable, tt.twofactor, tt.skey, tt.reqCerts); res != want {
@@ -595,8 +642,8 @@ func TestUpdatePAMsshdPamless(t *testing.T) {
 
 	for idx, tt := range tests {
 		t.Run(fmt.Sprintf("test-%d", idx), func(t *testing.T) {
-			contents := strings.Join(tt.contents, "\n")
-			want := strings.Join(tt.want, "\n")
+			contents := strings.Join(tt.contents, "\n") + "\n"
+			want := strings.Join(tt.want, "\n") + "\n"
 
 			if res := updatePAMsshdPamless(contents, tt.enable, tt.twofactor); res != want {
 				t.Errorf("want:\n%v\ngot:\n%v\n", want, res)
@@ -667,8 +714,8 @@ func TestUpdateGroupConf(t *testing.T) {
 	}
 
 	for idx, tt := range tests {
-		contents := strings.Join(tt.contents, "\n")
-		want := strings.Join(tt.want, "\n")
+		contents := strings.Join(tt.contents, "\n") + "\n"
+		want := strings.Join(tt.want, "\n") + "\n"
 
 		if res := updateGroupConf(contents, tt.enable); res != want {
 			t.Errorf("test %v\nwant:\n%v\ngot:\n%v\n", idx, want, res)
