@@ -33,7 +33,7 @@ if [[ ! -f "$GUEST_AGENT_REPO/Makefile" ]]; then
     # This is a placeholder file for guest-agent package, google-compute-engine-windows.goospec
     # looks for this file during goopack packaging and will fail if not found.
     echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > GCEWindowsAgentManager.exe
-    echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > ggactl_plugin_cleanup.exe
+    echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > ggactl_plugin.exe
     echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > GCEWindowsCompatManager.exe
     echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > CorePlugin.exe
     echo "This is a placeholder file so guest agent package build without error. Package will have actual Guest Agent Manager executable instead if both repos are cloned side-by-side." > GCEMetadataScriptRunner.exe
@@ -46,7 +46,7 @@ fi
 BUILD_DIR=$(pwd)
 pushd $GUEST_AGENT_REPO
 GOOS=windows VERSION=$version make cmd/google_guest_agent/google_guest_agent
-GOOS=windows VERSION=$version make cmd/ggactl/ggactl_plugin_cleanup
+GOOS=windows VERSION=$version make cmd/ggactl/ggactl_plugin
 GOOS=windows VERSION=$version make cmd/google_guest_compat_manager/google_guest_compat_manager
 GOOS=windows VERSION=$version make cmd/core_plugin/core_plugin
 GOOS=windows VERSION=$version make cmd/gce_metadata_script_runner/gce_metadata_script_runner
@@ -55,7 +55,7 @@ GOOS=windows VERSION=$version make cmd/google_authorized_keys_compat/google_auth
 GOOS=windows VERSION=$version make cmd/google_authorized_keys/google_authorized_keys
 
 cp cmd/google_guest_agent/google_guest_agent $BUILD_DIR/GCEWindowsAgentManager.exe
-cp cmd/ggactl/ggactl_plugin_cleanup $BUILD_DIR/ggactl_plugin_cleanup.exe
+cp cmd/ggactl/ggactl_plugin $BUILD_DIR/ggactl_plugin.exe
 cp cmd/google_guest_compat_manager/google_guest_compat_manager $BUILD_DIR/GCEWindowsCompatManager.exe
 cp cmd/core_plugin/core_plugin $BUILD_DIR/CorePlugin.exe
 cp cmd/gce_metadata_script_runner/gce_metadata_script_runner $BUILD_DIR/GCEMetadataScriptRunner.exe
